@@ -14,7 +14,9 @@ def main():
     # %% Initiate sgems pjt
     cwd = os.getcwd()  # Working directory
     rdir = join_path(cwd, "results", "demo_sgsim")  # Results directory
-    pjt = sg.Sgems(project_name="sgsim_test", project_wd=cwd, res_dir=rdir, verbose=True)
+    pjt = sg.Sgems(
+        project_name="sgsim_test", project_wd=cwd, res_dir=rdir, verbose=True
+    )
 
     # %% Load hard data point set
     data_dir = join_path(cwd, "datasets", "demo_sgsim")
