@@ -1,4 +1,4 @@
-#  Copyright (c) 2020. Robin Thibaut, Ghent University
+#  Copyright (c) 2022. Robin Thibaut, Ghent University
 from os.path import join as jp
 
 import matplotlib.pyplot as plt
@@ -45,7 +45,7 @@ class Plots(Package):
         plt.grid("blue")
         plt.show()
 
-    def plot_2d(self, name, res_file=None, save=False):
+    def plot_2d(self, name, res_file=None, save=False, show=True):
         """Rudimentary 2D plot
 
         :param name: name of the plot
@@ -75,4 +75,6 @@ class Plots(Package):
         plt.colorbar()
         if save:
             plt.savefig(jp(self.parent.res_dir, name), bbox_inches="tight", dpi=300)
-        plt.show()
+        if show:
+            plt.show()
+        plt.close()
